@@ -485,13 +485,15 @@ def _extract_name_from_single_func_def(src: str, default=None):
 FuncSource = Union[Callable[[str], Callable], Mapping[str, Callable]]
 
 
-def _ensure_func_src(func_src: FuncSource) -> Callable[[str], Callable]:
+def _ensure_func_src(
+    func_src: FuncSource, use_place_holder_fallback=False
+) -> Callable[[str], Callable]:
     if isinstance(func_src, Mapping):
         name_to_func_map = func_src
         func_src = partial(
             dlft_factory_to_func,
             name_to_func_map=name_to_func_map,
-            use_place_holder_fallback=False,
+            use_place_holder_fallback=use_place_holder_fallback,
         )
     assert isinstance(func_src, Callable), f'func_src should be callable, or a mapping'
     return func_src
@@ -499,10 +501,14 @@ def _ensure_func_src(func_src: FuncSource) -> Callable[[str], Callable]:
 
 @double_up_as_factory
 def code_to_dag(
-    src=None, *, func_src: FuncSource = dlft_factory_to_func, name: str = None
+    src=None,
+    *,
+    func_src: FuncSource = dlft_factory_to_func,
+    use_place_holder_fallback=False,
+    name: str = None,
 ) -> DAG:
     """Get a ``meshed.DAG`` from src code"""
-    func_src = _ensure_func_src(func_src)
+    func_src = _ensure_func_src(func_src, use_place_holder_fallback)
     # Get a name for the dag (if src is a str
     if name is None:
         if isinstance(src, str):
